mimetools.Message

mimetools :: Message :: Class Message |
[hide private]
[frames] | no frames]

# Class Message

A derived class of rfc822.Message that knows about MIME headers and contains some hooks for decoding encoded and multipart messages.

Instance Methods | [hide private]
__init__(self, fp, seekable=1) Initialize the class instance and read the headers. |
getencoding(self) |
getmaintype(self) |
getparam(self, name) |
getparamnames(self) |
getplist(self) |
getsubtype(self) |
gettype(self) |
parseplist(self) |
parsetype(self) |
Inherited from `rfc822.Message`: `__contains__`, `__delitem__`, `__getitem__`, `__iter__`, `__len__`, `__setitem__`, `__str__`, `get`, `getaddr`, `getaddrlist`, `getallmatchingheaders`, `getdate`, `getdate_tz`, `getfirstmatchingheader`, `getheader`, `getheaders`, `getrawheader`, `has_key`, `iscomment`, `isheader`, `islast`, `items`, `keys`, `readheaders`, `rewindbody`, `setdefault`, `values`

Method Details | [hide private]

### __init__(self, fp, seekable=1) (Constructor) |
Initialize the class instance and read the headers. Overrides: rfc822.Message.__init__ (inherited documentation)